%define gettext_package dbus

%define expat_version           1.95.5
%define libselinux_version      1.15.2

%define dbus_user_uid           81

Summary: D-BUS message bus
Name: dbus
Epoch: 1
Version: 1.2.24
Release: 7%{?dist}
URL: http://www.freedesktop.org/software/dbus/
Source0: http://dbus.freedesktop.org/releases/dbus/%{name}-%{version}.tar.gz
Source1: doxygen_to_devhelp.xsl
Source2: 00-start-message-bus.sh
License: GPLv2+ or AFL
Group: System Environment/Libraries
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires: libtool
BuildRequires: expat-devel >= %{expat_version}
BuildRequires: libselinux-devel >= %{libselinux_version}
BuildRequires: audit-libs-devel >= 0.9
BuildRequires: libX11-devel
BuildRequires: libcap-ng-devel
BuildRequires: gettext
BuildRequires: doxygen
BuildRequires: xmlto
BuildRequires: libxslt

Requires: chkconfig >= 1.3.26
Requires: libselinux >= %{libselinux_version}
Requires: dbus-libs = %{epoch}:%{version}-%{release}
Requires(pre): /usr/sbin/useradd

# Conflict with cups prior to configuration file change, so that the
# %postun service condrestart works.
Conflicts: cups < 1:1.1.20-4

Patch0: bindir.patch
Patch1: dbus-1.0.1-generate-xml-docs.patch
# Backported from upstream dbus-1.2
Patch2: 0001-Fix-use-of-servicename-in-status.patch

Patch3: dbus-1.2.24-CVE-2010-4352.patch

# These two combined fix CVE-2011-2200
Patch4: 0001-_dbus_header_byteswap-change-the-first-byte-of-the-m.patch
Patch5: 0001-dbus_message_demarshal_bytes_needed-correct-a-wrong-.patch

Patch6: 0001-CVE-2012-3524-Don-t-access-environment-variables-or-.patch

%description
D-BUS is a system for sending messages between applications. It is
used both for the system-wide message bus service, and as a
per-user-login-session messaging facility.

%package libs
Summary: Libraries for accessing D-BUS
Group: Development/Libraries
Obsoletes: dbus < 1.1.2-3

%description libs
This package contains lowlevel libraries for accessing D-BUS.

%package doc
Summary: Developer documentation for D-BUS
Group: Documentation
Requires: %name = %{epoch}:%{version}-%{release}
Requires: devhelp
BuildArch: noarch

%description doc
This package contains developer documentation for D-Bus along with
other supporting documentation such as the introspect dtd file.

%package devel
Summary: Development files for D-BUS
Group: Development/Libraries
Requires: %name = %{epoch}:%{version}-%{release}
Requires: pkgconfig

%description devel
This package contains libraries and header files needed for
developing software that uses D-BUS.

%package x11
Summary: X11-requiring add-ons for D-BUS
Group: Development/Libraries
Requires: %name = %{epoch}:%{version}-%{release}

%description x11
D-BUS contains some tools that require Xlib to be installed, those are
in this separate package so server systems need not install X.

%prep
%setup -q

# For some reason upstream ships these files as executable
# Make sure they are not
/bin/chmod 0644 COPYING ChangeLog NEWS

%patch0 -p1 -b .bindir
%patch1 -p1 -b .generate-xml-docs
%patch2 -p1 -b .service
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1

autoreconf -f -i

%build
COMMON_ARGS="--enable-libaudit --enable-selinux=yes --with-init-scripts=redhat --with-system-pid-file=%{_localstatedir}/run/messagebus.pid --with-dbus-user=dbus --libdir=/%{_lib} --bindir=/bin --sysconfdir=/etc --exec-prefix=/ --libexecdir=/%{_lib}/dbus-1"

# leave verbose mode so people can debug their apps but make sure to
# turn it off on stable releases with --disable-verbose-mode
%configure $COMMON_ARGS --disable-tests --disable-asserts --enable-doxygen-docs --enable-xml-docs
make

doxygen Doxyfile

xsltproc -o dbus.devhelp %{SOURCE1} doc/api/xml/index.xml

%install
rm -rf %{buildroot}

make install DESTDIR=%{buildroot}

mkdir -p %{buildroot}/%{_libdir}/pkgconfig

#change the arch-deps.h include directory to /usr/lib[64] instead of /lib[64]
sed -e 's@-I${libdir}@-I${prefix}/%{_lib}@' %{buildroot}/%{_lib}/pkgconfig/dbus-1.pc > %{buildroot}/%{_libdir}/pkgconfig/dbus-1.pc
rm -f %{buildroot}/%{_lib}/pkgconfig/dbus-1.pc

mkdir -p %{buildroot}/%{_bindir}
mv -f %{buildroot}/bin/dbus-launch %{buildroot}/%{_bindir}
mkdir -p %{buildroot}/%{_libdir}/dbus-1.0/include/
mv -f %{buildroot}/%{_lib}/dbus-1.0/include/* %{buildroot}/%{_libdir}/dbus-1.0/include/
rm -rf %{buildroot}/%{_lib}/dbus-1.0

rm -f %{buildroot}/%{_lib}/*.a
rm -f %{buildroot}/%{_lib}/*.la

# FIXME put all this goo upstream in make install
mkdir -p %{buildroot}%{_datadir}/devhelp/books/dbus
mkdir -p %{buildroot}%{_datadir}/devhelp/books/dbus/api

cp dbus.devhelp %{buildroot}%{_datadir}/devhelp/books/dbus
cp doc/dbus-specification.html %{buildroot}%{_datadir}/devhelp/books/dbus
cp doc/dbus-faq.html %{buildroot}%{_datadir}/devhelp/books/dbus
cp doc/dbus-tutorial.html %{buildroot}%{_datadir}/devhelp/books/dbus
cp doc/api/html/* %{buildroot}%{_datadir}/devhelp/books/dbus/api
cp doc/diagram.png %{buildroot}%{_datadir}/devhelp/books/dbus
cp doc/diagram.svg %{buildroot}%{_datadir}/devhelp/books/dbus

install -D -m755 %{SOURCE2} %{buildroot}%{_sysconfdir}/X11/xinit/xinitrc.d/00-start-message-bus.sh

mkdir -p %{buildroot}%{_datadir}/dbus-1/interfaces

## %find_lang %{gettext_package}

%clean
rm -rf %{buildroot}

%pre
# Add the "dbus" user and group
/usr/sbin/groupadd -r -g %{dbus_user_uid} dbus 2>/dev/null || :
/usr/sbin/useradd -c 'System message bus' -u %{dbus_user_uid} -g %{dbus_user_uid} \
	-s /sbin/nologin -r -d '/' dbus 2> /dev/null || :

%post libs -p /sbin/ldconfig

%post
/sbin/chkconfig --add messagebus
/sbin/chkconfig messagebus resetpriorities

%preun
if [ $1 = 0 ]; then
    /sbin/service messagebus stop
    /sbin/chkconfig --del messagebus
fi

%postun libs -p /sbin/ldconfig


%files
%defattr(-,root,root)

%doc COPYING

%dir %{_sysconfdir}/dbus-1
%config %{_sysconfdir}/dbus-1/*.conf
%{_sysconfdir}/rc.d/init.d/*
%dir %{_sysconfdir}/dbus-1/system.d
%dir %{_sysconfdir}/dbus-1/session.d
%dir %{_localstatedir}/run/dbus
%dir %{_localstatedir}/lib/dbus/
/bin/dbus-daemon
/bin/dbus-send
/bin/dbus-cleanup-sockets
/bin/dbus-monitor
/bin/dbus-uuidgen
%{_mandir}/man*/dbus-cleanup-sockets.1.gz
%{_mandir}/man*/dbus-daemon.1.gz
%{_mandir}/man*/dbus-monitor.1.gz
%{_mandir}/man*/dbus-send.1.gz
%{_mandir}/man*/dbus-uuidgen.1.gz
%dir %{_datadir}/dbus-1
%{_datadir}/dbus-1/services
%{_datadir}/dbus-1/system-services
%{_datadir}/dbus-1/interfaces
%dir /%{_lib}/dbus-1
# See doc/system-activation.txt in source tarball for the rationale
# behind these permissions
%attr(4750,root,dbus) /%{_lib}/dbus-1/dbus-daemon-launch-helper


%files libs
%defattr(-,root,root,-)
/%{_lib}/*dbus-1*.so.*

%files x11
%defattr(-,root,root)

%{_bindir}/dbus-launch
%{_datadir}/man/man*/dbus-launch.1.gz
%{_sysconfdir}/X11/xinit/xinitrc.d/00-start-message-bus.sh

%files doc
%defattr(-,root,root)
%doc doc/introspect.dtd doc/introspect.xsl doc/system-activation.txt
%doc %{_datadir}/devhelp/books/dbus

%files devel
%defattr(-,root,root)

/%{_lib}/lib*.so
%dir %{_libdir}/dbus-1.0
%{_libdir}/dbus-1.0/include/
%{_libdir}/pkgconfig/dbus-1.pc
%{_includedir}/*


%changelog

